@@ -59,21 +59,24 @@ class BaseWidget(Box):
             try:
                 with open(template_path, "r") as f:
                     json_data = json.load(f)
-                    if "modelJson" not in json_data:
-                        raise KeyError(
-                            f"Required keys can not be found in {template_path}"
-                        )
-                    else:
-                        self.chart_template = {
-                            "chart_template": json_data,
-                            "template_path": template_path,
-                        }
-                        self._template_path = template_path.replace(".json", "")
             except FileNotFoundError:
-                raise FileNotFoundError(f"Can not read {template_path}")
+                raise FileNotFoundError(f"No such template file: {template_path!r}")
+            required = {"modelJson"}
+            missing = required.difference(json_data)
+            if missing:
+                raise KeyError(
+                    f"Required keys {sorted(missing)} not found in {template_path}"
+                )
+            else:
+                self.chart_template = {
+                    "chart_template": json_data,
+                    "template_path": template_path,
+                }
+                self._template_path = template_path.replace(".json", "")
         else:
             self.chart_template = {}
             self._template_path = ""
+
         if hasattr(data, "__iter__"):
             root = System("chart_viewer")
             for sys in data:
@@ -87,6 +90,7 @@ class BaseWidget(Box):
                     sys.computed.connect(self.computed_notification)
 
             self.init_value(root, **kwargs)
+
         else:
             self.init_value(data, **kwargs)
 
@@ -223,7 +227,7 @@ class BaseWidget(Box):
     def register(self, Cls: Type[BaseComponent], **kwargs) -> None:
         key = Cls.name
         if key in self.__component:
-            raise KeyError(f"Component {key!r} already registed")
+            raise KeyError(f"Component {key!r} already registered")
         
         self.__component[key] = component = Cls(
             self._system, self.sys_data, self.send, **kwargs
