@@ -487,14 +487,17 @@ class SysExplorer(Box):
         for child in system.children.values():
             SysExplorer.default_add_shape(r, child)
 
-        def filter_shapes(p: "ExtensiblePort") -> "bool":
-            return (
-                p.__class__.__name__ == "GeometryPort"
-                and p.visible
-                and p.shape is not None
-            )
+        def filter_shapes(p: "Port") -> bool:
+            try:
+                shape = p.shape
+                visible = p.visible
+            except AttributeError:
+                return False
+            else:
+                return visible and shape is not None
 
         for port in filter(filter_shapes, system.outputs.values()):
+            # print(f"{port.owner.full_name()}.{port.name}")
             if isinstance(port.shape, List):
                 r.extend(port.shape)
             else:
@@ -556,18 +559,15 @@ class SysExplorer(Box):
 
         else:
 
+            add_shape = self.add_shape or SysExplorer.default_add_shape
             r = []
-            if self.add_shape is not None:
 
-                self.add_shape(r, sys)
-            else:
-                try:
-                    SysExplorer.default_add_shape(r, sys)
-                except:
-                    pass
+            try:
+                add_shape(r, sys)
+            except:
+                pass
 
-            shape_data = OccParser(r)
-            return shape_data
+            return OccParser(r)
 
     def save_data(self, **kwarg) -> None:
         """Callback function used to get geometry data and log value
