@@ -1,15 +1,13 @@
 import copy
 import json
-import pickle
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 from weakref import ref
 import numbers
-import numpy as np
+import numpy
 from cosapp.drivers import Driver
 from cosapp.drivers.time.interfaces import ExplicitTimeDriver
 from cosapp.ports.enum import PortType
-from cosapp.ports import Port
-from cosapp.ports.port import Variable
+from cosapp.ports.port import Variable, BasePort
 from cosapp.systems import System
 from cosapp.drivers import NonLinearSolver
 from .cosapp_parser import CosappParser
@@ -141,33 +139,26 @@ class CosappObjectParser(CosappParser):
 
         Returns
         -------
-        Union[str, Dict]
+        Union[str, Dict[str, Any]]
             A dictionary with keys are the contextual name of the variables, value
             are a list of 2 value, first one is de type of data and second one is
             the value of data.
         """
-        ret = {}
-        for var_path in self.variable_list:
-            real_value = self._system()[var_path]
-            val_type = type(real_value).__name__
-            key = f"{self.system_name}.{var_path}"
-            if is_jsonable(real_value):
-                ret[key] = [val_type, real_value]
+        content = {}
+        system = self._system()
+        for var_name in self.variable_list:
+            value = system[var_name]
+            if is_jsonable(value):
+                pkl_str = value
+            elif isinstance(value, numpy.ndarray):
+                pkl_str = value.tolist()
             else:
-                if val_type == "ndarray":
-                    pkl_str = real_value.tolist()
-                else:
-                    try:
-                        pkl = pickle.dumps(real_value, protocol=0)
-                        pkl_str = pkl.decode("utf-8")
-                    except Exception as e:
-                        # print("error", e)
-                        pkl_str = "non-jsonable"
-                ret[key] = [val_type, pkl_str]
-        if dumps:
-            return json.dumps(ret)
-        else:
-            return ret
+                pkl_str = "non-jsonable"
+            key = f"{system.name}.{var_name}"
+            typename = type(value).__name__
+            content[key] = [typename, pkl_str]
+        
+        return json.dumps(content) if dumps else content
 
     def serialize_recorder(self) -> Dict:
         """Serialize all dataframe recorder in system.
@@ -270,7 +261,7 @@ class CosappObjectParser(CosappParser):
                         try:
                             size = len(value)
                             if serializable:
-                                if isinstance(value, np.ndarray):
+                                if isinstance(value, numpy.ndarray):
                                     value = self._system()[var_path].tolist()
                         except:
                             size = 1
@@ -559,9 +550,9 @@ class CosappObjectParser(CosappParser):
         except:
             recorder_data = current_driver.recorder.data
         if isinstance(current_driver, ExplicitTimeDriver):
-            reference = np.array(recorder_data["Reference"], dtype=float)
+            reference = numpy.array(recorder_data["Reference"], dtype=float)
             try:
-                value = np.array(recorder_data[var_name], dtype=float)
+                value = numpy.array(recorder_data[var_name], dtype=float)
             except ValueError:
                 value = recorder_data[var_name].values
             ret = ("time", reference.tolist(), value.tolist())
@@ -593,13 +584,12 @@ class CosappObjectParser(CosappParser):
             system = self.get_system_from_name(sys)
             ret[sys] = {}
             for port_name in data["port_list"]:
-
-                port: Port = system[port_name]
+                port: BasePort = system[port_name]
                 ret[sys][port_name] = self.port_to_dict(port)
 
         return ret
 
-    def port_to_dict(self, port: Port) -> Dict:
+    def port_to_dict(self, port: BasePort) -> Dict:
         """
         Convert a CoSApp port to a python dict
         """
@@ -621,26 +611,44 @@ class CosappObjectParser(CosappParser):
         dict
             The dictionary representing this variable.
         """
-        ret = {
-            "unit": var.unit or None,
-            "invalid_comment": var.invalid_comment or None,
-            "out_of_limits_comment": var.out_of_limits_comment or None,
-            "desc": var.description or None,
-            "distribution": var.distribution.__json__() if var.distribution else None,
+        def get_attr(name, transform = lambda a: a or None):
+            try:
+                attr = getattr(var, name)
+            except AttributeError:
+                return None
+            return transform(attr)
+
+        result = {}
+        mapping = {
+            "unit": "unit",
+            "desc": "description",
+            "invalid_comment": "invalid_comment",
+            "out_of_limits_comment": "out_of_limits_comment",
         }
+        for key, name in mapping.items():
+            result[key] = get_attr(name)
+        
+        result["distribution"] = get_attr(
+            "distribution",
+            lambda d: d.__json__() if d else None
+        )
 
         for key in ["valid_range", "limits"]:
             try:
-                tmp_val = list(getattr(var, key))
-                for idx, val in enumerate(tmp_val):
-                    if np.isinf(val):
-                        tmp_val[idx] = str(val)
-                if tmp_val == ["-inf", "inf"]:
-                    tmp_val = None
+                range_attr = getattr(var, key)
+            except AttributeError:
+                continue
             except:
-                tmp_val = None
-            ret[key] = tmp_val
+                range_attr = None
+            else:
+                range_attr = list(map(
+                    lambda x: x if numpy.isfinite(x) else None,
+                    range_attr
+                ))
+                if range_attr == [None, None]:
+                    range_attr = None
+            result[key] = range_attr
 
-        return (
-            ret  # { key: value for (key, value) in ret.items() if value is not None }
-        )
+        # Filter out None values
+        # return dict(filter(lambda it: it[1] is not None, result.items()))
+        return result
