@@ -125,36 +125,31 @@ class OccParser:
         if T is None:
             return
 
-        nTri = T.NbTriangles()
-        nVtx = T.NbNodes()
         vtx = []
+        for node in self.get_nodes(T):
+            vtx.extend(node.Coord(d) for d in range(1, 4))
         idx = []
-        nodes = T.Nodes()
-        tri = T.Triangles()
-        trf = loc.Transformation()
-        for pt in nodes:
-            for d in range(1, 4):
-                vtx.append(pt.Coord(d))
-        for t in tri:
-            for i in range(1, 4):
-                idx.append(t.Value(i) - 1)
+        for triangle in self.get_triangles(T):
+            idx.extend(triangle.Value(d) - 1 for d in range(1, 4))
 
         faces = numpy.array(idx, "uint16")
-        ret_faces = faces.tolist()
+        trf = loc.Transformation()
+        translation = trf.TranslationPart()
+        quaternion = trf.GetRotation()
         self.threejs_data[self.shape_idx].append(
             {
                 # "vertices": vtx,
-                # "faces": ret_faces,
+                # "faces": faces.tolist(),
                 "pos": [
-                    trf.TranslationPart().X(),
-                    trf.TranslationPart().Y(),
-                    trf.TranslationPart().Z(),
+                    translation.X(),
+                    translation.Y(),
+                    translation.Z(),
                 ],
                 "quat": [
-                    trf.GetRotation().X(),
-                    trf.GetRotation().Y(),
-                    trf.GetRotation().Z(),
-                    trf.GetRotation().W(),
+                    quaternion.X(),
+                    quaternion.Y(),
+                    quaternion.Z(),
+                    quaternion.W(),
                 ],
                 "color": color,
                 "transparent": transparent,
@@ -196,23 +191,25 @@ class OccParser:
                     loc = OCC_Core.TopLoc.TopLoc_Location()
                     tri = OCC_Core.BRep.BRep_Tool().Triangulation(face, loc)
                     trf = loc.Transformation()
+                    translation = trf.TranslationPart()
+                    quaternion = trf.GetRotation()
                     # polygon = Poly.PolygonOnTriangulation(edge, face, loc)
                     polygon = OCC_Core.BRep.BRep_Tool().PolygonOnTriangulation(edge, tri, loc)
 
                     self.threejs_data[f"edge_{self.shape_idx}"].append(
                         {
                             "vertices": vertexBuffer,
-                            "faces": [i - 1 for i in polygon.Nodes()],
+                            "faces": list(range(polygon.NbNodes())),
                             "pos": [
-                                trf.TranslationPart().X(),
-                                trf.TranslationPart().Y(),
-                                trf.TranslationPart().Z(),
+                                translation.X(),
+                                translation.Y(),
+                                translation.Z(),
                             ],
                             "quat": [
-                                trf.GetRotation().X(),
-                                trf.GetRotation().Y(),
-                                trf.GetRotation().Z(),
-                                trf.GetRotation().W(),
+                                quaternion.X(),
+                                quaternion.Y(),
+                                quaternion.Z(),
+                                quaternion.W(),
                             ],
                         }
                     )
@@ -225,3 +222,12 @@ class OccParser:
         brepbndlib.Add(shape, box)
         x_min, y_min, z_min, x_max, y_max, z_max = box.Get()
         return max(x_max - x_min, y_max - y_min, z_max - z_min) * 2e-2
+
+    @staticmethod
+    def get_nodes(T):
+        for i in range(T.NbNodes()):
+            yield T.Node(i + 1)
+
+    @staticmethod
+    def get_triangles(T):
+        yield from T.Triangles()
