@@ -36,22 +36,21 @@ def replicate_dict_structure(x: Dict) -> Dict:
     for key, current_val in x.items():
         if is_jsonable(current_val):
             new_dict[key] = copy.deepcopy(current_val)
+        elif isinstance(current_val, dict):
+            new_dict[key] = replicate_dict_structure(current_val)
         else:
-            if isinstance(current_val, dict):
-                new_dict[key] = replicate_dict_structure(current_val)
-            else:
-                new_dict[key] = None
+            new_dict[key] = None
     return new_dict
 
 
 def get_nonexistant_path(fname_path):
-
     if not os.path.exists(fname_path):
         return fname_path
-    filename, file_extension = os.path.splitext(fname_path)
+    filename, extension = os.path.splitext(fname_path)
+    get_name = lambda i: f"{filename}-{i}{extension}"
     i = 1
-    new_fname = "{}-{}{}".format(filename, i, file_extension)
+    new_fname = get_name(i)
     while os.path.exists(new_fname):
         i += 1
-        new_fname = "{}-{}{}".format(filename, i, file_extension)
+        new_fname = get_name(i)
     return new_fname
